@@ -153,7 +153,7 @@ class TestWriteJs:
     Tests for the ``write_js()`` function.
     """
 
-    def test_can_write_file(self, js_path: pathlib.Path) -> None:
+    def test_write_file(self, js_path: pathlib.Path) -> None:
         """
         Writing to a file stores the correct JavaScript string.
         """
@@ -166,7 +166,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_str(self, tmp_path: pathlib.Path) -> None:
+    def test_write_to_str(self, tmp_path: pathlib.Path) -> None:
         """
         It can write to a path passed as a ``str``.
         """
@@ -181,7 +181,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_path(self, tmp_path: pathlib.Path) -> None:
+    def test_write_to_path(self, tmp_path: pathlib.Path) -> None:
         """
         It can write to a path passed as a ``pathlib.Path``.
         """
@@ -196,7 +196,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_file(self, tmp_path: pathlib.Path) -> None:
+    def test_write_to_file(self, tmp_path: pathlib.Path) -> None:
         """
         It can write to a file.
         """
@@ -212,7 +212,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_binary_file(self, tmp_path: pathlib.Path) -> None:
+    def test_write_to_binary_file(self, tmp_path: pathlib.Path) -> None:
         """
         It can write to a file opened in binary mode.
         """
@@ -228,7 +228,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_string_buffer(self) -> None:
+    def test_write_to_string_buffer(self) -> None:
         """
         It can write to a string buffer.
         """
@@ -243,7 +243,7 @@ class TestWriteJs:
             == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
-    def test_can_write_to_bytes_buffer(self) -> None:
+    def test_write_to_bytes_buffer(self) -> None:
         """
         It can write to a binary buffer.
         """
@@ -258,6 +258,32 @@ class TestWriteJs:
             == b'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
         )
 
+    def test_write_with_sort_keys(self, tmp_path: pathlib.Path) -> None:
+        """
+        If you pass `sort_keys=True`, it sorts the keys in JSON objects.
+        """
+        red_pentagon = {"sides": 5, "colour": "red"}
+
+        unsorted_path = tmp_path / "unsorted.js"
+        sorted_path = tmp_path / "sorted.js"
+
+        write_js(
+            unsorted_path,
+            value=red_pentagon,
+            varname="redPentagon",
+            sort_keys=False,
+        )
+        assert (
+            unsorted_path.read_text()
+            == 'const redPentagon = {\n  "sides": 5,\n  "colour": "red"\n};\n'
+        )
+
+        write_js(sorted_path, value=red_pentagon, varname="redPentagon", sort_keys=True)
+        assert (
+            sorted_path.read_text()
+            == 'const redPentagon = {\n  "colour": "red",\n  "sides": 5\n};\n'
+        )
+
     def test_fails_if_file_is_read_only(self, tmp_path: pathlib.Path) -> None:
         """
         It cannot write to a file open in read-only mode.
